summaryrefslogtreecommitdiff
path: root/examples/download_avatars.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/download_avatars.py')
-rwxr-xr-xexamples/download_avatars.py133
1 files changed, 57 insertions, 76 deletions
diff --git a/examples/download_avatars.py b/examples/download_avatars.py
index 64300cff..408c2146 100755
--- a/examples/download_avatars.py
+++ b/examples/download_avatars.py
@@ -1,33 +1,21 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2012 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
-import sys
import logging
-import getpass
-import threading
-from optparse import OptionParser
+from getpass import getpass
+from argparse import ArgumentParser
-import sleekxmpp
-from sleekxmpp.exceptions import XMPPError
-
-
-# Python versions before 3.0 do not use UTF-8 encoding
-# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
-# ourselves to UTF-8.
-if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
- setdefaultencoding('utf8')
-else:
- raw_input = input
+import slixmpp
+from slixmpp.exceptions import XMPPError
+from slixmpp import asyncio
FILE_TYPES = {
@@ -37,23 +25,29 @@ FILE_TYPES = {
}
-class AvatarDownloader(sleekxmpp.ClientXMPP):
+class AvatarDownloader(slixmpp.ClientXMPP):
"""
A basic script for downloading the avatars for a user's contacts.
"""
def __init__(self, jid, password):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
- self.add_event_handler("session_start", self.start, threaded=True)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
+ self.add_event_handler("session_start", self.start)
self.add_event_handler("changed_status", self.wait_for_presences)
self.add_event_handler('vcard_avatar_update', self.on_vcard_avatar)
self.add_event_handler('avatar_metadata_publish', self.on_avatar)
self.received = set()
- self.presences_received = threading.Event()
+ self.presences_received = asyncio.Event()
+ self.roster_received = asyncio.Event()
+
+ def roster_received_cb(self, event):
+ self.roster_received.set()
+ self.presences_received.clear()
+ @asyncio.coroutine
def start(self, event):
"""
Process the session_start event.
@@ -68,16 +62,20 @@ class AvatarDownloader(sleekxmpp.ClientXMPP):
data.
"""
self.send_presence()
- self.get_roster()
+ self.get_roster(callback=self.roster_received_cb)
print('Waiting for presence updates...\n')
- self.presences_received.wait(15)
- self.disconnect(wait=True)
+ yield from self.roster_received.wait()
+ print('Roster received')
+ yield from self.presences_received.wait()
+ self.disconnect()
+ @asyncio.coroutine
def on_vcard_avatar(self, pres):
print("Received vCard avatar update from %s" % pres['from'].bare)
try:
- result = self['xep_0054'].get_vcard(pres['from'], cached=True)
+ result = yield from self['xep_0054'].get_vcard(pres['from'].bare, cached=True,
+ timeout=5)
except XMPPError:
print("Error retrieving avatar for %s" % pres['from'])
return
@@ -88,16 +86,18 @@ class AvatarDownloader(sleekxmpp.ClientXMPP):
pres['from'].bare,
pres['vcard_temp_update']['photo'],
filetype)
- with open(filename, 'w+') as img:
+ with open(filename, 'wb+') as img:
img.write(avatar['BINVAL'])
+ @asyncio.coroutine
def on_avatar(self, msg):
print("Received avatar update from %s" % msg['from'])
metadata = msg['pubsub_event']['items']['item']['avatar_metadata']
for info in metadata['items']:
if not info['url']:
try:
- result = self['xep_0084'].retrieve_avatar(msg['from'], info['id'])
+ result = yield from self['xep_0084'].retrieve_avatar(msg['from'].bare, info['id'],
+ timeout=5)
except XMPPError:
print("Error retrieving avatar for %s" % msg['from'])
return
@@ -106,7 +106,7 @@ class AvatarDownloader(sleekxmpp.ClientXMPP):
filetype = FILE_TYPES.get(metadata['type'], 'png')
filename = 'avatar_%s_%s.%s' % (msg['from'].bare, info['id'], filetype)
- with open(filename, 'w+') as img:
+ with open(filename, 'wb+') as img:
img.write(avatar['value'])
else:
# We could retrieve the avatar via HTTP, etc here instead.
@@ -117,6 +117,7 @@ class AvatarDownloader(sleekxmpp.ClientXMPP):
Wait to receive updates from all roster contacts.
"""
self.received.add(pres['from'].bare)
+ print((len(self.received), len(self.client_roster.keys())))
if len(self.received) >= len(self.client_roster.keys()):
self.presences_received.set()
else:
@@ -125,60 +126,40 @@ class AvatarDownloader(sleekxmpp.ClientXMPP):
if __name__ == '__main__':
# Setup the command line arguments.
- optp = OptionParser()
- optp.add_option('-q','--quiet', help='set logging to ERROR',
- action='store_const',
- dest='loglevel',
- const=logging.ERROR,
- default=logging.ERROR)
- optp.add_option('-d','--debug', help='set logging to DEBUG',
- action='store_const',
- dest='loglevel',
- const=logging.DEBUG,
- default=logging.ERROR)
- optp.add_option('-v','--verbose', help='set logging to COMM',
- action='store_const',
- dest='loglevel',
- const=5,
- default=logging.ERROR)
+ parser = ArgumentParser()
+ parser.add_argument("-q","--quiet", help="set logging to ERROR",
+ action="store_const",
+ dest="loglevel",
+ const=logging.ERROR,
+ default=logging.ERROR)
+ parser.add_argument("-d","--debug", help="set logging to DEBUG",
+ action="store_const",
+ dest="loglevel",
+ const=logging.DEBUG,
+ default=logging.ERROR)
# JID and password options.
- optp.add_option("-j", "--jid", dest="jid",
- help="JID to use")
- optp.add_option("-p", "--password", dest="password",
- help="password to use")
- opts,args = optp.parse_args()
+ parser.add_argument("-j", "--jid", dest="jid",
+ help="JID to use")
+ parser.add_argument("-p", "--password", dest="password",
+ help="password to use")
+
+ args = parser.parse_args()
# Setup logging.
- logging.basicConfig(level=opts.loglevel,
+ logging.basicConfig(level=args.loglevel,
format='%(levelname)-8s %(message)s')
- if opts.jid is None:
- opts.jid = raw_input("Username: ")
- if opts.password is None:
- opts.password = getpass.getpass("Password: ")
+ if args.jid is None:
+ args.jid = input("Username: ")
+ if args.password is None:
+ args.password = getpass("Password: ")
- xmpp = AvatarDownloader(opts.jid, opts.password)
+ xmpp = AvatarDownloader(args.jid, args.password)
xmpp.register_plugin('xep_0054')
xmpp.register_plugin('xep_0153')
xmpp.register_plugin('xep_0084')
- # If you are working with an OpenFire server, you may need
- # to adjust the SSL version used:
- # xmpp.ssl_version = ssl.PROTOCOL_SSLv3
-
- # If you want to verify the SSL certificates offered by a server:
- # xmpp.ca_certs = "path/to/ca/cert"
-
# Connect to the XMPP server and start processing XMPP stanzas.
- if xmpp.connect():
- # If you do not have the dnspython library installed, you will need
- # to manually specify the name of the server if it does not match
- # the one in the JID. For example, to use Google Talk you would
- # need to use:
- #
- # if xmpp.connect(('talk.google.com', 5222)):
- # ...
- xmpp.process(block=True)
- else:
- print("Unable to connect.")
+ xmpp.connect()
+ xmpp.process()
@@ -1,33 +1,21 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2012 Nathanael C. Fritz